package com.usky.dxtop.controller.web.business;


import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.usky.dxtop.common.core.domain.ApiResult;
import com.usky.dxtop.common.core.page.CommonPage;
import com.usky.dxtop.common.exception.CustomException;
import com.usky.dxtop.model.Charge;
import com.usky.dxtop.model.Staff;
import com.usky.dxtop.service.ChargeService;
import com.usky.dxtop.service.StaffService;
import com.usky.dxtop.service.vo.ChargeRequest;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import java.util.Map;
import java.util.Optional;

/**
 * 充值模块
 * @author yq
 * @since 2021-09-09
 */
@RestController
@RequestMapping("/dxtop/charge")
public class ChargeController {


    @Autowired
    private ChargeService chargeService;

    @Autowired
    private StaffService staffService;

    /**
     * 记录查询
     * @param chargeRequest
     * @return
     */
    @PostMapping("/page")
    public ApiResult<CommonPage<Charge>> page(@Validated @RequestBody ChargeRequest chargeRequest){
        return ApiResult.success(chargeService.page(chargeRequest));
    }

    /**
     * 充值和消费记录
     * @param chargeRequest
     * @return
     */
    @PostMapping("/cordPage")
    public ApiResult<CommonPage<Map<String,Object>>> cordPage(@Validated @RequestBody ChargeRequest chargeRequest){
        return ApiResult.success(chargeService.cordPage(chargeRequest));
    }

    /**
     * 充值详情
     * @param seq
     * @return
     */
    @GetMapping(value = "/{seq}")
    public ApiResult<Charge> one(@PathVariable Long seq){
        return ApiResult.success(chargeService.one(seq));
    }

    /**
     * 批量修改消息状态
     * @return
     */
    @PutMapping
    public ApiResult<Boolean> updateList(@RequestParam String userId){
        Staff staff = staffService.one(userId, null, null);
        Optional.ofNullable(staff).orElseThrow(() -> new CustomException("用户信息不存在"));
        LambdaUpdateWrapper<Charge> updateWrapper = Wrappers.lambdaUpdate();
        updateWrapper.set(Charge::getMessageFlag,true)
                .eq(Charge::getCard,staff.getCardId());
        return ApiResult.success(chargeService.update(updateWrapper));
    }
}

