package com.usky.dxtop.controller.web.business;


import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.usky.dxtop.common.annotation.RepeatSubmit;
import com.usky.dxtop.common.core.domain.ApiResult;
import com.usky.dxtop.common.core.page.CommonPage;
import com.usky.dxtop.common.utils.DateUtils;
import com.usky.dxtop.controller.BaseController;
import com.usky.dxtop.model.Order;
import com.usky.dxtop.service.OrderService;
import com.usky.dxtop.service.emun.OrderStatus;
import com.usky.dxtop.service.vo.OrderRequest;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.Date;

/**
 * 订单表
 *
 * @author yq
 * @since 2021-08-26
 */
@RestController
@RequestMapping("/dxtop/order")
public class OrderController extends BaseController {

    @Autowired
    private OrderService orderService;

    /**
     * 添加订单(现金支付)
     * @param order
     * @return
     */
    @RepeatSubmit
    @PostMapping
    public ApiResult add(@RequestBody Order order){
        return toAjax(orderService.add(order));
    }

    /**
     * 修改订单状态
     * @param order
     * @return
     */
    @PutMapping
    public ApiResult update(@RequestBody Order order){
        order.setOrderFlag(OrderStatus.COMPLETE.getCode());
        return toAjax(orderService.updateById(order));
    }

    /**
     * 删除订单
     * @param orderNumber
     * @return
     */
    @DeleteMapping("/{orderNumber}")
    public ApiResult remove(@PathVariable("orderNumber") String orderNumber){
        return toAjax(orderService.remove(orderNumber));
    }

    /**
     * 记录查询
     * @param orderRequest
     * @return
     */
    @PostMapping("/list")
    public ApiResult<CommonPage<Order>> list(@RequestBody OrderRequest orderRequest){
        return ApiResult.success(orderService.list(orderRequest));
    }

    /**
     * 扫码支付
     * @param order
     * @return
     */
    @RepeatSubmit
    @PostMapping("/topScanPayApi")
    public ApiResult<String> getTopScanPayApi(@RequestBody Order order){
        return ApiResult.success(orderService.getTopScanPayApi(order));
    }

    /**
     * 查看订单详情
     * @param orderNumber
     * @return
     */
    @GetMapping("/{orderNumber}")
    public ApiResult<String> callTopFindOrderInfoApi(@PathVariable("orderNumber") String orderNumber){
        return ApiResult.success(orderService.callTopFindOrderInfoApi(orderNumber));
    }

    /**
     * 订单详情导出
     * @param orderRequest
     * @return
     */
    @PostMapping("/exportDetail")
    public ApiResult<String> exportDetail(@RequestBody OrderRequest orderRequest){
        return ApiResult.success(orderService.exportDetail(orderRequest));
    }

    /**
     * 订单报表
     * @param current
     * @param size
     * @param startTime
     * @param endTime
     * @param type
     * @return
     */
    @GetMapping("/orderReportList")
    public ApiResult orderReportList(@RequestParam Integer current,
                                     @RequestParam Integer size,
                                     @RequestParam(required = false) Date startTime,
                                     @RequestParam(required = false) Date endTime,
                                     @RequestParam Integer type){
        return ApiResult.success(orderService.orderReportList(current,size,startTime,endTime,type));
    }

    /**
     * 订单报表导出
     * @param startTime
     * @param endTime
     * @param type
     * @return
     */
    @GetMapping("/reportExport")
    public ApiResult<String> reportExport(@RequestParam(required = false) Date startTime,
                                  @RequestParam(required = false) Date endTime,
                                  @RequestParam Integer type){
        return ApiResult.success(orderService.reportExport(startTime, endTime, type));
    }

    /**
     * 统一支付
     * @param order
     * @return
     */
    @RepeatSubmit
    @PostMapping("/callUnifiedPay")
    public ApiResult<String> callUnifiedPay(@RequestBody Order order){
        return ApiResult.success(orderService.callUnifiedPay(order));
    }

    /**
     * 支付方式汇总
     * @return
     */
    @GetMapping("/payTypeCollect")
    public ApiResult payTypeCollect(){
        return ApiResult.success(orderService.payTypeCollect());
    }

    /**
     * 充值金额/充值次数
     * @return
     */
    @GetMapping("/orderMoney")
    public ApiResult orderMoney(){
        Date date = new Date();
        QueryWrapper<Order> queryWrapper = new QueryWrapper<>();
        queryWrapper.select("IFNULL(sum(money),0) as total","count(*) as count")
                .and(wrapper -> wrapper.eq("order_flag",OrderStatus.SUCCESS.getCode()).or().eq("order_flag",OrderStatus.COMPLETE.getCode()))
                .between("create_time",DateUtils.getDayStartTime(date),date);
        return ApiResult.success(orderService.getMap(queryWrapper));
    }

    /**
     * 充值记录日期统计图表
     * @param type
     * @return
     */
    @GetMapping("/dateCollect")
    public ApiResult dateCollect(@RequestParam Integer type,
                                 @RequestParam Date startTime,
                                 @RequestParam Date endTime){
        return ApiResult.success(orderService.dateCollect(type,startTime,endTime));
    }

    /**
     * 支付路径
     * @param order
     * @return
     */
    @RepeatSubmit
    @PostMapping("/backPayPath")
    public ApiResult backPayPath(@RequestBody Order order){
        return ApiResult.success(orderService.backPayPath(order));
    }


}

