package com.usky.dxtop.controller.web.business;

import com.usky.dxtop.common.core.domain.ApiResult;
import com.usky.dxtop.common.core.page.CommonPage;
import com.usky.dxtop.common.exception.CustomException;
import com.usky.dxtop.model.Staff;
import com.usky.dxtop.model.StaffRadio;
import com.usky.dxtop.service.DeptService;
import com.usky.dxtop.service.StaffRadioService;
import com.usky.dxtop.service.StaffService;
import com.usky.dxtop.service.vo.StaffRequest;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Optional;

/**
 * 充值记录
 * @author yq
 * @date 2021/9/23 13:34
 */
@RestController
@RequestMapping("/dxtop/staff")
public class StaffController {

    @Autowired
    private StaffRadioService staffRadioService;

    @Autowired
    private StaffService staffService;
    @Autowired
    private DeptService deptService;

    /**
     * 汇总
     * @return
     */
    @RequestMapping("count")
    public ApiResult count(){
        return ApiResult.success(staffService.count());
    }


    /**
     * 批量新增
     * @param list
     * @return
     */
    @PutMapping("/addList")
    public ApiResult addList(@RequestBody List<StaffRadio> list){
        staffRadioService.addList(list);
        return ApiResult.success();
    }
    /**
     * 人员比例
     * @return
     */
    @GetMapping("staffRadio")
    public ApiResult staffRadio(){
        return ApiResult.success(staffRadioService.staffRadio());
    }

    /**
     * 记录查询
     * @param staffRequest
     * @return
     */
    @PostMapping("page")
    public ApiResult<CommonPage<Staff>> page(@RequestBody StaffRequest staffRequest){
        return ApiResult.success(staffService.page(staffRequest));
    }

    /**
     * 获取余额信息
     * @param card
     * @return
     */
    @GetMapping("cardBalance")
    public ApiResult getCardBalance(@RequestParam String card){
        return ApiResult.success(staffService.getBalance(card));
    }

    /**
     * 获取用户详情
     * @param id
     * @param phone
     * @param card
     * @return
     */
    @GetMapping("one")
    public ApiResult<Staff> getCardBalance(@RequestParam(required = false) String id,
                                    @RequestParam(required = false) String phone,
                                    @RequestParam(required = false) String card){
        return ApiResult.success(staffService.one(id,phone,card));
    }

    /**
     * 修改消息状态
     * @param staff
     * @return
     */
    @PutMapping
    public ApiResult<Void> update(@RequestBody Staff staff){
        Staff one = staffService.one(staff.getId(), null, staff.getCardId());
        Optional.ofNullable(one).map(s -> {
            s.setOpenId(staff.getOpenId());
            return staffService.updateById(s);
        }).orElseThrow(() ->  new CustomException("用户信息不存在"));
        return ApiResult.success();
    }

}
