package com.usky.dxtop.controller.web.business;

import com.usky.dxtop.common.core.domain.ApiResult;
import com.usky.dxtop.service.api.TopApiConfiger;
import com.usky.dxtop.service.api.WxApi;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

/**
 * 微信
 * @author yq
 * @date 2021/9/22 10:04
 */
@Slf4j
@RestController
public class WxController {

    @Autowired
    private TopApiConfiger topApiConfiger;

    @Autowired
    private WxApi wxApi;

    /**
     * 微信登录
     * @param jsCode
     * @return
     */
    @GetMapping("/wxLogin")
    public ApiResult<String> wxLogin(@RequestParam String jsCode){
        return ApiResult.success(wxApi.wxLogin(topApiConfiger.getWxAppId(), topApiConfiger.getWxAppSecret(), jsCode));
    }

    /**
     * 拉起支付
     * @param url
     * @return
     */
    @GetMapping("/wxAccToken")
    public ApiResult getAccToken(@RequestParam String url){
        return ApiResult.success(wxApi.getPayParam(topApiConfiger.getWxAppId(), topApiConfiger.getWxAppSecret(), url));
    }

    /**
     * 获取token
     * @return
     */
    @GetMapping("/accentToken")
    public ApiResult<String> getToken(@RequestParam Integer type){
        String token;
        if (1 == type){
            token =  wxApi.getToken(topApiConfiger.getWxAppId(),topApiConfiger.getWxAppSecret());
        }else {
            token =  wxApi.getToken(WxApi.APP_ID,WxApi.SECRET);
        }
        return ApiResult.success(token);
    }

    /**
     * 公众号进行消息推送
     * @param openId
     * @param data
     * @param templateId
     * @param detailUrl
     * @return
     */
    @GetMapping("/offSendMessage")
    public ApiResult<String> offSendMessageT(@RequestParam String openId,
                                     @RequestParam Object data,
                                     @RequestParam String templateId,
                                     @RequestParam(required = false) String detailUrl){
        return ApiResult.success(wxApi.sendMessageApi(openId, data, wxApi.getToken(WxApi.APP_ID, WxApi.SECRET), templateId, detailUrl));
    }

    /**
     * 公众号获取openid
     * @param code
     * @return
     */
    @GetMapping("/offOpenId")
    public ApiResult<String> getOpenId(@RequestParam String code){
        return ApiResult.success(wxApi.getOpenId(WxApi.APP_ID, WxApi.SECRET, code));
    }
}
