package com.usky.dxtop.service;

import com.baomidou.mybatisplus.extension.service.IService;
import com.usky.dxtop.common.core.page.CommonPage;
import com.usky.dxtop.model.Order;
import com.usky.dxtop.service.vo.OrderReport;
import com.usky.dxtop.service.vo.OrderRequest;

import java.util.Date;
import java.util.List;
import java.util.Map;


/**
 * <p>
 * 订单表 服务类
 * </p>
 *
 * @author yq
 * @since 2021-08-26
 */
public interface OrderService extends IService<Order> {


    /**
     * 添加订单(现金支付)
     * @param order
     * @return
     */
    boolean add(Order order);

    /**
     * 删除订单
     * @param orderNumber
     * @return
     */
    boolean remove(String orderNumber);


    Order one(String orderNumber);

    CommonPage<Order> list(OrderRequest orderRequest);

    /**
     * 扫码支付api
     * @param order
     * @return
     */
    String getTopScanPayApi(Order order);

    /**
     * 查看订单详情api
     * @param orderNumber
     * @return
     */
    String callTopFindOrderInfoApi(String orderNumber);

    /**
     * 调用卡充值api
     * @param order
     * @return
     */
    void callCardTopApi(Order order);

    /**
     * 处理订单
     * @param order
     * @param result
     * @param param
     */
    void checkOrder(Order order,String result,String param);

    /**
     * 处理支付成功的订单
     * @param order
     */
    void paySuccess(Order order);


    /**
     * 明细导出
     * @param orderRequest
     * @return
     */
    String exportDetail(OrderRequest orderRequest);

    /**
     * 订单报表
     * @param current
     * @param size
     * @param startTime
     * @param endTime
     * @param type
     * @return
     */
    CommonPage<OrderReport> orderReportList(Integer current,Integer size,Date startTime,Date endTime,Integer type);

    /**
     * 报表导出
     * @param startTime
     * @param endTime
     * @param type
     * @return
     */
    String reportExport(Date startTime,Date endTime,Integer type);

    /**
     * 调用统一支付api(app充值)
     * @param order
     * @return
     */
    String callUnifiedPay(Order order);

    /**
     * 支付方式汇总
     * @return
     */
    List<Map<String,Object>> payTypeCollect();

    /**
     * @param dateType(0月1年)
     * 日期汇总
     * @return
     */
    List<Map<String,Object>> dateCollect(Integer dateType,Date startTime,Date endTime);

    /**
     * 后台充值支付页面
     * @param order
     * @return
     */
    String backPayPath(Order order);

}
