package com.usky.dxtop.service.impl;

import cn.afterturn.easypoi.excel.ExcelExportUtil;
import cn.afterturn.easypoi.excel.entity.ExportParams;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.usky.dxtop.common.core.domain.model.LoginUser;
import com.usky.dxtop.common.core.page.CommonPage;
import com.usky.dxtop.common.exception.CustomException;
import com.usky.dxtop.common.utils.*;
import com.usky.dxtop.common.utils.http.HttpUtils;
import com.usky.dxtop.mapper.OrderMapper;
import com.usky.dxtop.model.*;
import com.usky.dxtop.service.*;
import com.usky.dxtop.service.api.TopApiConfiger;
import com.usky.dxtop.service.config.rabbitmq.charge.ChargeConsumeConfig;
import com.usky.dxtop.service.constant.MsgLogBusinessCode;
import com.usky.dxtop.service.emun.AsyncResultType;
import com.usky.dxtop.service.emun.OrderPayType;
import com.usky.dxtop.service.emun.OrderSceneCode;
import com.usky.dxtop.service.emun.OrderStatus;
import com.usky.dxtop.service.vo.ChargeVO;
import com.usky.dxtop.service.vo.OrderExport;
import com.usky.dxtop.service.vo.OrderReport;
import com.usky.dxtop.service.vo.OrderRequest;
import lombok.extern.slf4j.Slf4j;
import ma.glasnost.orika.MapperFacade;
import ma.glasnost.orika.MapperFactory;
import ma.glasnost.orika.impl.DefaultMapperFactory;
import org.apache.poi.ss.usermodel.Workbook;
import org.springframework.amqp.rabbit.connection.CorrelationData;
import org.springframework.amqp.rabbit.core.RabbitTemplate;
import org.springframework.aop.framework.AopContext;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.scheduling.annotation.Async;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.multipart.MultipartFile;

import java.io.IOException;
import java.math.BigDecimal;
import java.util.*;
import java.util.stream.Collectors;

/**
 * <p>
 * 订单表 服务实现类
 * </p>
 *
 * @author yq
 * @since 2021-08-26
 */
@Slf4j
@Service
public class OrderServiceImpl extends ServiceImpl<OrderMapper, Order> implements OrderService {

    public static final String SCAN_PAY = "支付";

    public static final String FIND_ORDER_INFO = "交易查询";

    public static final String CARD_TOP = "卡充值";

    private TreeMap<String,Integer> treeMap = new TreeMap<>();
    @Autowired
    private CallApiLogService callApiLogService;

    @Autowired
    @Qualifier(ChargeConsumeConfig.TEMPLATE)
    private RabbitTemplate rabbitTemplate;

    @Autowired
    private StaffRadioService staffRadioService;
    @Autowired
    private TopRadioService topRadioService;
    @Autowired
    private TopChannelService topChannelService;
    @Autowired
    private MsgLogService msgLogService;

    @Autowired
    private StaffService staffService;
    @Autowired
    private ISysAsyncTaskService sysAsyncTaskService;
    @Autowired
    private SysFileService sysFileService;
    @Autowired
    private TopApiConfiger topApiConfiger;
    @Autowired
    private ISysConfigService sysConfigService;

    @Transactional(rollbackFor = Exception.class)
    @Override
    public boolean add(Order order) {
        order.setPayType(OrderPayType.XJ.getPayCode());
        order.setScene(OrderSceneCode.BACK_STAGE.getCode());
        verifyOrder(order);
        this.save(order);
        callCardTopApi(order);
        return this.updateById(order);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public boolean remove(String orderNumber) {
        LambdaQueryWrapper<Order> queryWrapper = Wrappers.lambdaQuery();
        queryWrapper.eq(Order::getOrderNumber,orderNumber);
        this.remove(queryWrapper);
        LambdaQueryWrapper<CallApiLog> callApiQueryWrapper = Wrappers.lambdaQuery();
        callApiQueryWrapper.eq(CallApiLog::getOrderNumber,orderNumber);
        return callApiLogService.remove(callApiQueryWrapper);
    }

    @Override
    public Order one(String orderNumber){
        LambdaQueryWrapper<Order> queryWrapper = Wrappers.lambdaQuery();
        queryWrapper.eq(Order::getOrderNumber,orderNumber);
        return this.getOne(queryWrapper);
    }

    @Override
    public CommonPage<Order> list(OrderRequest orderRequest) {
        IPage<Order> page = new Page<>(orderRequest.getCurrent(), orderRequest.getSize());
        LambdaQueryWrapper<Order> queryWrapper = Wrappers.lambdaQuery();
        queryWrapper
                .like(StringUtils.isNotBlank(orderRequest.getUserName()),Order::getUserName,orderRequest.getUserName())
                .like(StringUtils.isNotBlank(orderRequest.getUserPhone()),Order::getUserPhone,orderRequest.getUserPhone())
                .eq(null != orderRequest.getPayType(),Order::getPayType,orderRequest.getPayType())
                .between(null != orderRequest.getStartMoney() && null != orderRequest.getEndMoney(),
                        Order::getMoney,orderRequest.getStartMoney(),orderRequest.getEndMoney())
                .between(null != orderRequest.getStartTime() && null != orderRequest.getEndTime(),
                        Order::getCreateTime,orderRequest.getStartTime(),orderRequest.getEndTime())
                .eq(null != orderRequest.getOrderFlag(),Order::getOrderFlag,orderRequest.getOrderFlag())
                .orderByDesc(Order::getId);
        page = this.page(page, queryWrapper);
        return new CommonPage<>(page.getRecords(),page.getTotal(),page.getCurrent(),page.getSize());
    }


    /**
     * 东信扫码支付api
     * @param order
     * @return
     */
    @Transactional(rollbackFor = Exception.class)
    @Override
    public String getTopScanPayApi(Order order){
        verifyOrder(order);
        this.save(order);
        TreeMap<String, String> params = topApiConfiger.generateScanPayApiParam(order.getOrderNumber(),
                                        new Double(Arith.mul(order.getMoney().doubleValue(),100)).intValue(), null,
                null,null,null,null,null,null);
        //记录调用日志
        callApiLogService.saveOrUpdate(order.getOrderNumber(),SCAN_PAY, topApiConfiger.scanPayUrl,JSONObject.toJSONString(params),null);
        return String.format("%s?%s", topApiConfiger.scanPayUrl, topApiConfiger.generateParam(params));
    }

    /**
     * 查询支付订单api
     * @param orderNumber
     * @return
     */
    @Transactional(rollbackFor = Exception.class)
    @Override
    public String callTopFindOrderInfoApi(String orderNumber) {
        Order order = one(orderNumber);
        TreeMap<String, String> param = topApiConfiger.generateDealSelectParam(orderNumber, null, null, null);
        String format = topApiConfiger.generateParam(param);
        String result;
        try {
            result = HttpUtils.sendGet(topApiConfiger.dealSelectUrl, format,null);
        }catch (Exception e){
            log.error("调用查询订单异常:"+e.getMessage());
            throw new CustomException("调用查询订单异常:"+e.getMessage());
        }
        //处理订单
        checkOrder(order, result,JSONObject.toJSONString(param));
        //再此获取订单的最新状态
        order = one(orderNumber);
        return OrderStatus.parse(order.getOrderFlag()).getName();
    }

    @Override
    public void callCardTopApi(Order order) {
        boolean b = true;
        try {
            ChargeVO chargeVo = new ChargeVO();
            chargeVo.setAmt(order.getMoney());
            if (null != order.getRealMoney() && order.getRealMoney().compareTo(BigDecimal.ZERO)  != 0){
                chargeVo.setAmt(order.getRealMoney());
            }
            chargeVo.setCard(order.getCard());
            MsgLog msgLog = new MsgLog();
            msgLog.setBusinessId(String.format("%s%s",MsgLogBusinessCode.ORDER,order.getId()));
            msgLog.setExchange(ChargeConsumeConfig.NAME);
            msgLog.setRoutingKey(ChargeConsumeConfig.NAME);
            msgLog.setMsg(JSON.toJSONString(chargeVo));
            msgLogService.addOrUpdate(msgLog);
            chargeVo.setSeq(msgLog.getId());
            CorrelationData correlationData = new CorrelationData(msgLog.getId().toString());
            rabbitTemplate.convertAndSend(msgLog.getExchange(), msgLog.getRoutingKey(), chargeVo,correlationData);
        }catch (Exception e){
            b = false;
            log.error("---order---卡充值消息发送异常"+ e.getMessage());
        }
        if (b){
            //成功修改状态支付成功
            order.setOrderFlag(OrderStatus.SUCCESS.getCode());
        }else {
            //失败修改状态为卡充值失败
            order.setOrderFlag(OrderStatus.PAYMENT_ERROR_DEBIT.getCode());
        }
    }

    /**
     * 校验是否继续处理订单
     * @param orderNumber
     * @return
     */
    public boolean isCheckOrder(String orderNumber){
        Order order = one(orderNumber);
        //订单是未支付和支付中需要处理
        return OrderStatus.NO_PAYMENT.getCode().equals(order.getOrderFlag()) || OrderStatus.AWAIT_PAY.getCode().equals(order.getOrderFlag());
    }


    /**
     * 查询交易后处理订单
     * @param order
     */
    @Override
    public void checkOrder(Order order,String result,String param){
        JSONObject obj= JSON.parseObject(result);
        if ("0000".equals(obj.get("status").toString())){
            String trxstatus = obj.get("trxstatus").toString();
            //交易成功
            if ("2".equals(trxstatus)) {
                paySuccess(order);
            }else if ("0".equals(trxstatus)){
                //交易等待
                payWaiting(order);
            }else if ("1".equals(trxstatus)){
                Object msg = obj.get("msg");
                if (null != msg && "交易不存在".equals(msg.toString())){
                    long datePoorMin = DateUtils.getDatePoorMin(DateUtils.getNowDate(), order.getCreateTime());
                    if (datePoorMin > 31){
                        cancelPay(order);
                    }
                }else {
                    log.error("订单交易失败--------订单编号:"+order.getOrderFlag()+"-----异常:"+msg);
                    payError(order);
                }
            }
        }else {
            orderError(order);
        }
        callApiLogService.saveOrUpdate(order.getOrderNumber(), FIND_ORDER_INFO, topApiConfiger.dealSelectUrl, param, result);
    }

    /**
     * 充值成功后处理
     * @param order
     */
    @Transactional(rollbackFor = Exception.class)
    @Override
    public void paySuccess(Order order){
        if (isCheckOrder(order.getOrderNumber())){
            //判断是不是游客充值
            if (null == order.getUserId() || 0 == order.getUserId()){
                order.setOrderFlag(OrderStatus.COMPLETE.getCode());
            }else {
                //调用卡充值api
                callCardTopApi(order);
            }
            this.updateById(order);
        }
    }


    @Override
    public String exportDetail(OrderRequest orderRequest) {
        LoginUser loginUser = SecurityUtils.getLoginUser();
        SysUser user = loginUser.getUser();
        Long taskId = sysAsyncTaskService.getId(user.getUserName(), "订单详情");
        if (null == taskId) {
            throw new CustomException("获取次数太多了请稍后获取");
        }
        ((OrderServiceImpl) AopContext.currentProxy()).syncOrder(taskId,orderRequest);
        return String.valueOf(taskId);

    }

    @Async
    public void syncOrder(Long taskId,OrderRequest orderRequest){
        Workbook workbook = null;
        try {
            ExportParams params = new ExportParams(null, "订单详情");
            workbook = ExcelExportUtil.exportBigExcel(params, OrderExport.class,
                    (o, i) -> {
                        orderRequest.setCurrent(i);
                        orderRequest.setSize(30);
                        CommonPage<Order> page = this.list(orderRequest);
                        return page.getRecords().stream().map(this::orderChangeOrderExport).collect(Collectors.toList());
                    },null);
            if (null != workbook) {
                String fileName = String.format("%s.xls", "订单详情");
                MultipartFile multipartFile = ExcelUtils.downLoadExcel(workbook, fileName);
                uploadOrderFile(multipartFile,taskId);
            } else {
                sysAsyncTaskService.sendResult(taskId, false, "订单表格数据为空", AsyncResultType.TEXT);
            }
            log.info("订单详情导出完成");
        } catch (Exception e) {
            log.error("导出文件失败", e);
            sysAsyncTaskService.sendResult(taskId, false, "导出订单文件失败", AsyncResultType.TEXT);
        } finally {
            if (workbook != null) {
                try {
                    workbook.close();
                } catch (IOException e) {
                    log.error("===export spec=== 关闭workbook失败", e);
                }
            }
        }
    }

    public void uploadOrderFile(MultipartFile multipartFile, Long taskId){
        List<MultipartFile> list = new ArrayList<>();
        list.add(multipartFile);
        String batchNo = sysFileService.generateBatchNo();
        SysFile sysFile = new SysFile();
        sysFile.setBatchNo(batchNo);
        sysFile.setFiles(list);
        sysFile.setUploadType(SysFileServiceImpl.FILE);
        sysFile.setBusinessType("订单详情");
        sysFile.setExpriceAt(DateUtils.addDays(new Date(), 3));
        List<SysFile> sysFileList = sysFileService.addFile(sysFile);
        long count = sysFileList.stream().filter(sysFileDTO -> !sysFileDTO.getSuccess()).count();
        if (count > 0) {
            sysAsyncTaskService.sendResult(taskId, false, "上传文件失败", AsyncResultType.TEXT);
            return;
        }
        List<String> idList = sysFileList.stream().map(sf -> sf.getId().toString()).collect(Collectors.toList());
        boolean active = sysFileService.active(batchNo,idList);
        if (active) {
            sysAsyncTaskService.sendResult(taskId, true, batchNo, AsyncResultType.FILE);
        } else {
            sysAsyncTaskService.sendResult(taskId, false, "上传文件失败", AsyncResultType.TEXT);
        }
    }

    public OrderExport orderChangeOrderExport(Order order){
        MapperFactory factory = new DefaultMapperFactory.Builder().build();
        factory.classMap(Order.class, OrderExport.class)
                .exclude("orderFlag")
                .exclude("payType")
                .exclude("scene")
                .byDefault().register();
        MapperFacade mapper = factory.getMapperFacade();
        OrderExport orderExport = mapper.map(order, OrderExport.class);
        orderExport.setOrderFlag(OrderStatus.parse(order.getOrderFlag()).getName());
        orderExport.setPayType(OrderPayType.parse(order.getPayType()).getName());
        orderExport.setScene(OrderSceneCode.parse(order.getScene()).getName());
        return orderExport;
    }

    @Override
    public CommonPage<OrderReport> orderReportList(Integer current,Integer size,Date startTime, Date endTime, Integer type) {
        IPage<Map<String,Object>> page = new Page<>(current, size);
        String dateType;
        switch (type){
            case 1 :
                dateType = "DATE(create_time) reportDate";
                break;
            case 2 :
                dateType = "WEEK(create_time) reportDate";
                break;
            case 3 :
                dateType = "MONTH(create_time) reportDate";
                break;
            default:
                dateType = "YEAR(create_time) reportDate";
        }
        QueryWrapper<Order> queryWrapper = new QueryWrapper<>();
        queryWrapper.select(dateType,
                "cast(sum(money) AS decimal(15,2)) as totalMoney",
                "sum(if(pay_type = '1', money, 0)) as cashMoney",
                "sum(if(pay_type = '2', money, 0)) as wxMoney",
                "sum(if(pay_type = '3', money, 0)) as zfbMoney")
                .between(null != startTime && null != endTime,"create_time",startTime,endTime)
                .and(wrapper -> wrapper.eq("order_flag",OrderStatus.SUCCESS.getCode()).or().eq("order_flag",OrderStatus.COMPLETE.getCode()))
                .groupBy("reportDate")
                .orderByDesc("reportDate");
        IPage<Map<String, Object>> mapIPage = baseMapper.selectMapsPage(page, queryWrapper);
        String jsonStr = JSON.toJSONString(mapIPage.getRecords());
        List<OrderReport> orderReports = JSON.parseArray(jsonStr, OrderReport.class);
        return new CommonPage<>(orderReports,page.getTotal(),page.getCurrent(),page.getSize());
    }

    @Override
    public String reportExport(Date startTime, Date endTime, Integer type) {
        LoginUser loginUser = SecurityUtils.getLoginUser();
        SysUser user = loginUser.getUser();
        Long taskId = sysAsyncTaskService.getId(user.getUserName(), "订单报表");
        if (null == taskId) {
            throw new CustomException("获取次数太多了请稍后获取");
        }
        ((OrderServiceImpl) AopContext.currentProxy()).syncOrderBusiness(taskId,startTime,endTime,type);
        return String.valueOf(taskId);
    }
    @Async
    public void syncOrderBusiness(Long taskId,Date startTime, Date endTime, Integer type){
        Workbook workbook = null;
        try {
            ExportParams params = new ExportParams(null, "订单报表");
            workbook = ExcelExportUtil.exportBigExcel(params, OrderReport.class,
                    (o, i) -> {
                        CommonPage<OrderReport> list = this.orderReportList(i,30,startTime,endTime,type);
                        return new ArrayList<>(list.getRecords());
                    },null);
            if (null != workbook) {
                String fileName = String.format("%s.xls", "订单报表");
                MultipartFile multipartFile = ExcelUtils.downLoadExcel(workbook, fileName);
                uploadOrderBusinessFile(multipartFile,taskId);
            } else {
                sysAsyncTaskService.sendResult(taskId, false, "订单表格数据为空", AsyncResultType.TEXT);
            }
        } catch (Exception e) {
            log.error("导出文件失败", e);
            sysAsyncTaskService.sendResult(taskId, false, "导出订单文件失败", AsyncResultType.TEXT);
        } finally {
            if (workbook != null) {
                try {
                    workbook.close();
                } catch (IOException e) {
                    log.error("===export spec=== 关闭workbook失败", e);
                }
            }
        }
    }

    public void uploadOrderBusinessFile(MultipartFile multipartFile, Long taskId){
        List<MultipartFile> list = new ArrayList<>();
        list.add(multipartFile);
        String batchNo = sysFileService.generateBatchNo();
        SysFile sysFile = new SysFile();
        sysFile.setBatchNo(batchNo);
        sysFile.setFiles(list);
        sysFile.setUploadType(SysFileServiceImpl.FILE);
        sysFile.setBusinessType("订单报表");
        sysFile.setExpriceAt(DateUtils.addDays(new Date(), 3));
        List<SysFile> sysFileList = sysFileService.addFile(sysFile);
        long count = sysFileList.stream().filter(sysFileDTO -> !sysFileDTO.getSuccess()).count();
        if (count > 0) {
            sysAsyncTaskService.sendResult(taskId, false, "上传文件失败", AsyncResultType.TEXT);
            return;
        }
        List<String> idList = sysFileList.stream().map(sf -> sf.getId().toString()).collect(Collectors.toList());
        boolean active = sysFileService.active(batchNo,idList);
        if (active) {
            sysAsyncTaskService.sendResult(taskId, true, batchNo, AsyncResultType.FILE);
        } else {
            sysAsyncTaskService.sendResult(taskId, false, "上传文件失败", AsyncResultType.TEXT);
        }
    }


    @Transactional(rollbackFor = Exception.class)
    @Override
    public String callUnifiedPay(Order order) {
        String appId = null;
        String openId = null;
        if ("W06".equals(order.getTopPayType())){
            appId = topApiConfiger.wxAppId;
            openId = order.getOpenId();
        }
        verifyOrder(order);
        this.save(order);
        String orderNumber = order.getOrderNumber();
        TreeMap<String, String> params = topApiConfiger.generateUnifyParam(orderNumber,new Double(Arith.mul(order.getMoney().doubleValue(),100)).intValue(),
                topApiConfiger.notifyUrl, null,
                null,null,openId,order.getTopPayType(),null,appId,
                null,null,null,null);
        String unify = topApiConfiger.generateParam(params);
        String result;
        try {
            result = HttpUtils.sendGet(topApiConfiger.unifyUrl, unify,null);
        }catch (Exception e){
            throw new CustomException("调用统一支付接口异常:"+e.getMessage());
        }
        JSONObject obj= JSON.parseObject(result);
        String payInfo;
        if ("0000".equals(obj.get("status"))){
            payInfo = obj.get("payinfo").toString();
        }else {
            throw new CustomException(obj.get("errorMessage").toString());
        }
        //记录调用日志
        callApiLogService.saveOrUpdate(orderNumber,SCAN_PAY, topApiConfiger.scanPayUrl,JSONObject.toJSONString(params),null);
        return payInfo;
    }

    @Override
    public List<Map<String, Object>> payTypeCollect() {
        QueryWrapper<Order> queryWrapper = new QueryWrapper<>();
        queryWrapper.select("sum(money) as money","pay_type as payType")
                .and(wrapper -> wrapper.eq("order_flag",OrderStatus.SUCCESS.getCode()).or().eq("order_flag",OrderStatus.COMPLETE.getCode()))
                .groupBy("pay_type");
        List<Map<String, Object>> list = baseMapper.selectMaps(queryWrapper);
        for (OrderPayType orderPayType:OrderPayType.values()) {
            boolean present = list.stream().anyMatch(o -> o.get("payType").equals(orderPayType.getPayCode()));
            if (!present){
                Map<String,Object> map = new HashMap<>();
                map.put("payType",orderPayType.getPayCode());
                map.put("money",0.00);
                list.add(map);
            }
        }
        return list;
    }

    @Override
    public List<Map<String, Object>> dateCollect(Integer dateType,Date startTime,Date endTime) {
        String type;
        int times;
        QueryWrapper<Order> queryWrapper = new QueryWrapper<>();
        if (0 == dateType){
            type = "EXTRACT(DAY FROM create_time)";
            times = Integer.parseInt(DateUtils.getDay(endTime))+1;
        }else {
            type = "MONTH(create_time)";
            times = 13;
        }
        queryWrapper.select(String.format("%s%s",type,"as orderTime"),"IFNULL(sum(money),0) as total")
                .and(wrapper -> wrapper.eq("order_flag",OrderStatus.SUCCESS.getCode()).or().eq("order_flag",OrderStatus.COMPLETE.getCode()))
                .between("create_time",startTime,endTime)
                .groupBy("orderTime");
        List<Map<String, Object>> list = baseMapper.selectMaps(queryWrapper);
        perfectDate(list,times,1);
        list = list.stream()
                .sorted(Comparator.comparing(map -> Integer.valueOf(map.get("orderTime").toString())))
                .collect(Collectors.toList());
        return list;
    }

    @Override
    public String backPayPath(Order order) {
        verifyOrder(order);
        String payPath = sysConfigService.selectConfigByKey("app.pay.path");
        return String.format("%s?backOrder=%s", payPath, JSON.toJSON(order));
    }

    /**
     * 完善没有的数据
     * @param list
     * @param times
     * @param defaultTime
     */
    public void perfectDate(List<Map<String,Object>> list,Integer times,Integer defaultTime){
        for (int i = defaultTime; i < times; i++) {
            int finalI = i;
            list.stream()
                    .filter(asv -> Integer.parseInt(asv.get("orderTime").toString()) == finalI)
                    .findFirst()
                    .orElseGet(() -> {
                        Map<String,Object> map = new HashMap<>();
                        map.put("orderTime",finalI);
                        map.put("total",0.00);
                        list.add(map);
                        return map;
                    });
        }
    }

    /**
     * 充值失败后处理
     * @param order
     */
    public void payError(Order order){
        order.setOrderFlag(OrderStatus.PAYMENT_ERROR_NO_DEBIT.getCode());
        this.updateById(order);
    }

    /**
     * 处理等待中的订单
     * @param order
     */
    public void payWaiting(Order order){
        order.setOrderFlag(OrderStatus.AWAIT_PAY.getCode());
        this.updateById(order);
    }

    /**
     * 取消支付
     * @param order
     */
    public void cancelPay(Order order){
        order.setOrderFlag(OrderStatus.CANCEL_PAY.getCode());
        this.updateById(order);
    }

    /**
     * 10次查询过后都是失败
     * @param order
     */
    public void orderError(Order order){
        String orderNumber = order.getOrderNumber();
        if (treeMap.containsKey(orderNumber)){
            Integer count = treeMap.get(orderNumber);
            if (count >= 10){
                log.info("失败的次数"+count);
                payError(order);
                treeMap.remove(orderNumber);
            }else {
                if (OrderStatus.NO_PAYMENT.getCode().equals(order.getOrderFlag())){
                    payWaiting(order);
                }
                treeMap.put(orderNumber,count+1);
            }
        }else {
            treeMap.put(orderNumber,1);
        }
    }

    /**
     * 校验订单添加订单
     * @param order
     */
    public void verifyOrder(Order order){
        String orderNumber = TopApiConfiger.getOrderNumber();
        order.setOrderNumber(orderNumber);
        Assert.check(null != order.getPayType(),"请选择支付方式");
        Assert.check(null != order.getMoney() && order.getMoney().compareTo(BigDecimal.ZERO)  != 0,"请输入订单金额");
        BigDecimal money = order.getMoney();
        String[] str=money.toString().split("\\.");
        Assert.check(str[0].length() <= 10 && str[1].length() <= 2,"订单整数不能超过十位,小数不能超过两位");
        Assert.check(null != order.getScene(),"充值场景不能为空");
        //非游客充值
        if (!OrderSceneCode.VISITOR.getCode().equals(order.getScene())){
            Assert.check(null != order.getUserId() && 0 != order.getUserId(),"用户编号不能为空");
//            Assert.check(StringUtils.isNotBlank(order.getUserName()),"用户名称不能为空");
//            Assert.check(StringUtils.isNotBlank(order.getUserPhone()),"用户手机号不能为空");
            //app充值
            if (OrderSceneCode.ERP_APP.getCode().equals(order.getScene()) || OrderSceneCode.COMMON_APP.getCode().equals(order.getScene())) {
                Assert.check(StringUtils.isNotBlank(order.getTopPayType()), "请选择支付方式");
                if ("W06".equals(order.getTopPayType())) {
                    Assert.check(StringUtils.isNotBlank(order.getOpenId()), "openId不能为空");
                }
            }
            //添加身份信息和充值到账比例
            LambdaQueryWrapper<StaffRadio> queryWrapper = Wrappers.lambdaQuery();
            queryWrapper.eq(StaffRadio::getStaffId,order.getUserId())
                    .eq(StaffRadio::isDelFlag,0);
            StaffRadio staffRadio = staffRadioService.getOne(queryWrapper);
            Optional.ofNullable(staffRadio).ifPresent(sf ->{
                TopRadio topRadio = topRadioService.getById(staffRadio.getRadioId());
                Optional.ofNullable(topRadio).ifPresent(tr ->{
                    order.setIdentity(tr.getIdentity());
                    order.setTopRadio(tr.getProportion());
                    double mul = Arith.mul(order.getMoney().doubleValue(), order.getTopRadio());
                    order.setRealMoney(BigDecimal.valueOf(Arith.div(mul,1,2)));
                });
            });
            //添加卡号
            Staff staff = staffService.getById(order.getUserId());
            Optional.ofNullable(staff).orElseThrow(() -> new CustomException("用户信息不存在"));
            Optional.ofNullable(staff.getCardId()).orElseThrow(() -> new CustomException("卡号不能为空"));
            order.setCard(staff.getCardId());
            order.setUserName(staff.getName());
            order.setUserPhone(staff.getContacts());
            //判断卡同步成功
            Assert.check(staff.getIsSuccess(),"人员未同步失败或同步失败，请手动同步人员信息");
        }else {
            if (null != order.getChannelId() && 0 != order.getChannelId()){
                TopChannel topChannel = topChannelService.getById(order.getChannelId());
                Assert.check(null != topChannel,"渠道信息不存在");
                order.setChannelId(topChannel.getId().intValue());
                order.setChannelName(topChannel.getName());
            }else {
                Assert.check(StringUtils.isNotBlank(order.getChannelName()),"渠道名称不能为空");
                order.setChannelName(order.getChannelName());
            }
        }
    }
}
