package com.usky.dxtop.service.job;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.usky.dxtop.common.utils.StringUtils;
import com.usky.dxtop.common.utils.http.HttpUtils;
import com.usky.dxtop.model.Dept;
import com.usky.dxtop.model.Staff;
import com.usky.dxtop.service.DeptService;
import com.usky.dxtop.service.StaffService;
import com.usky.dxtop.service.api.SmApi;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.Date;
import java.util.List;
import java.util.Map;
import java.util.TreeMap;
import java.util.function.Function;

/**
 * 世贸定时任务
 *
 * @author yq
 * @date 2021/9/28 14:47
 */
@Component("smJob")
@Slf4j
public class SmJob {

    @Autowired
    private StaffService staffService;

    @Autowired
    private DeptService deptService;

//    @Scheduled(cron = "0 0 0 */1 * ?")
    public void personExecute(String param) {
        PersonParam personParam = JSON.parseObject(param, PersonParam.class);
        personApi(personParam);
        log.info("smJob-person 定时任务完成");
    }

    public void groupExecute(String param) {
        GroupParam groupParam = JSON.parseObject(param, GroupParam.class);
        groupApi(groupParam);
        log.info("smJob-group 定时任务完成");
    }


    public void  personApi(PersonParam personParam){
        TreeMap<String, Object> treeMap;
        if (null != personParam){
            treeMap = SmApi.generatePersonParam(personParam.getId(),
                    personParam.getDeptIds(), personParam.getCreateTime(), personParam.getBlurry());
        }else {
            treeMap = SmApi.generatePersonParam(null,
                    null, null, null);
        }
        common(SmApi.PERSON_URL,treeMap,staffList -> {
            List<Staff> list = staffList.toJavaList(Staff.class);
            list.forEach(date -> {
                try {
                    LambdaQueryWrapper<Staff> queryWrapper = Wrappers.lambdaQuery();
                    queryWrapper.eq(Staff::getId,date.getId());
                    Staff staff = staffService.getOne(queryWrapper);
                    //获取部门信息
                    Map deptMap = JSON.parseObject(date.getDept(), Map.class);
                    LambdaQueryWrapper<Dept> deptLambdaQueryWrapper = Wrappers.lambdaQuery();
                    deptLambdaQueryWrapper.eq(Dept::getId,deptMap.get("id").toString());
                    Dept dept = deptService.getOne(deptLambdaQueryWrapper);
                    int type;
                    if (null == staff){
                        type = 1;
                        staffService.save(date);
                    }else {
                        type = 2;
                        date.setSId(staff.getSId());
                        staffService.updateById(date);
                    }
                    //发送人员信息
                    if (StringUtils.isNotBlank(date.getCardId()) && null != dept && Double.parseDouble(date.getCardId()) > 60000){
                        date.setDeptId(dept.getDId());
                        staffService.personSendMessage(date,type);
                        //发送人脸信息
                        if (StringUtils.isNotBlank(date.getFaceId())){
                            staffService.faceSendMessage(date);
                        }
                    }
                }catch (Exception e){
                    log.error("smJob-person:"+e.getMessage());
                }
            });
            return list.isEmpty();
        });
    }

    public void groupApi(GroupParam groupParam){
        TreeMap<String, Object> treeMap;
        if (null != groupParam){
            treeMap = SmApi.generateDeptParam(groupParam.getCreateTime(),
                    groupParam.getName(),groupParam.getPid(),groupParam.getEnable());
        }else {
            treeMap = SmApi.generateDeptParam(null,
                    null,null,null);
        }
        common(SmApi.DEPT_URL,treeMap,deptList -> {
            List<Dept> list = deptList.toJavaList(Dept.class);
            list.forEach(date -> {
                try {
                    //只负责同步
                    LambdaQueryWrapper<Dept> queryWrapper = Wrappers.lambdaQuery();
                    queryWrapper.eq(Dept::getId,date.getId());
                    if (StringUtils.isBlank(date.getPid())){
                        date.setPid("0");
                    }
                    deptService.saveOrUpdate(date,queryWrapper);
                }catch (Exception e){
                    log.error("smJob-group:"+e.getMessage());
                }
            });
            return list.isEmpty();
        });
        //拼接父子结构发送数据
        List<Dept> list = deptService.list();
        deptService.buildDeptTree(list);
    }

    public void common(String url, TreeMap<String,Object> param, Function<JSONArray,Boolean> function){
        boolean isNext = true;
        int page = 0;
        int size = 200;
        while (isNext) {
            try {
                String personUrl = String.format("%s?page=%s&size=%s", url, page, size);
                String result = HttpUtils.sendPost(personUrl, JSONObject.toJSONString(param), SmApi.sign(param));
                JSONObject jsonObject = JSONObject.parseObject(result);
                if ("200".equals(jsonObject.get("status").toString())) {
                    JSONObject data = jsonObject.getJSONObject("data");
                    JSONArray content = data.getJSONArray("content");
                    if (content != null && content.size() > 0) {
                        if (function.apply(content)) {
                            isNext = false;
                        } else {
                            page++;
                        }
                    } else {
                        isNext = false;
                    }
                } else {
                    break;
                }
            } catch (Exception e) {
                log.info("smJob异常" + e);
                break;
            }
        }
    }



    @Data
    public static class PersonParam {
        private String id;
        private List<String> deptIds;
        private List<Date> createTime;
        private String blurry;
    }


    @Data
    public static class GroupParam {
        private String name;
        private Boolean enable;
        private List<Date> createTime;
        private String pid;
    }
}
