package com.usky.dxtop.service.listener;

import com.alibaba.fastjson.JSONObject;
import com.usky.dxtop.common.utils.DateUtils;
import com.usky.dxtop.common.utils.StringUtils;
import com.usky.dxtop.model.Dish;
import com.usky.dxtop.model.Staff;
import com.usky.dxtop.service.DishService;
import com.usky.dxtop.service.StaffService;
import com.usky.dxtop.service.api.WxApi;
import com.usky.dxtop.service.config.rabbitmq.DishTransConfig;
import lombok.extern.slf4j.Slf4j;
import org.springframework.amqp.core.Message;
import org.springframework.amqp.rabbit.annotation.RabbitListener;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.nio.charset.StandardCharsets;
import java.util.HashMap;
import java.util.Map;

/**
 * @author yq
 * @date 2021/9/9 11:05
 */
@Slf4j
@Component
public class DishTransMqListener {


    private static final String URL = "https://smartpark.caih.com/vuepay/#/record?id=2";
    @Autowired
    private DishService dishService;
    @Autowired
    private StaffService staffService;
    @Autowired
    private WxApi wxApi;
    @RabbitListener(queues = DishTransConfig.NAME, containerFactory = DishTransConfig.LISTENER)
    public void dealDeclareMessage(Message message) {
        try {
            //消息类型
            String routingKey = message.getMessageProperties().getReceivedRoutingKey();
            log.info(routingKey);
            //消息内容
            String s = new String(message.getBody(), StandardCharsets.UTF_8);
            log.info("dish_trade_produce获取到的消息"+s);
            Dish dish = JSONObject.parseObject(s, Dish.class);;
            dishService.saveOrUpdate(dish);
            //更新用户余额
            Staff staff = staffService.one(null, null, dish.getCard());
            staff.setBalance(dish.getBalance());
            staffService.updateById(staff);
            if (StringUtils.isNotBlank(staff.getOpenId())){
                wxApi.sendMessageApi(staff.getOpenId(),getMessageData(dish),wxApi.getToken(WxApi.APP_ID,WxApi.SECRET), WxApi.DISH_TEMPLATE_ID,URL);
            }
        } catch (Exception e) {
            log.info("dish_trade_produce"+"异常信息：" + e.getMessage());
        }
    }

    public Map<String,Object> getMessageData(Dish dish){
        Map<String, Object> map = new HashMap<>();
        map.put("first",getMap("尊敬的客户，您的订单已支付成功",null));
        map.put("keyword1",getMap(dish.getSeq(),null));
        map.put("keyword2",getMap(dish.getShopName(),null));
        map.put("keyword3",getMap(String.format("%s%s", dish.getAmt()," 元"),null));
        map.put("keyword4",getMap(DateUtils.format(dish.getCreateTime(),null),null));
        map.put("keyword5",getMap(DateUtils.format(dish.getCreateTime(),null),null));
        map.put("remark",getMap("如有疑问，请及时在线联系我们的客服！",null));
        return map;
    }

    public Map<String,Object> getMap(Object value,String color){
        Map<String,Object> map = new HashMap<>();
        map.put("value",value);
        map.put("color",color);
        return map;
    }
}
